'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _express = require('express');

var _express2 = _interopRequireDefault(_express);

var _nodeBits = require('node-bits');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = function (app, config) {
  var router = _express2.default.Router(); // eslint-disable-line

  var callHooks = function callHooks(action, args) {
    _lodash2.default.forEach(config.hooks, function (hook) {
      if (!hook[action]) {
        return;
      }

      hook[action](args);
    });
  };

  var args = { app: app, router: router, routes: config.routes, database: config.database };

  callHooks(_nodeBits.BEFORE_CONFIGURE_ROUTES, args);

  _lodash2.default.forEach(config.routes, function (routeDefinition) {
    if (!routeDefinition) {
      return;
    }

    var verb = routeDefinition.verb,
        route = routeDefinition.route,
        implementation = routeDefinition.implementation;

    // only accept certain verbs

    if (!verb || !_nodeBits.VERBS.includes(verb.toUpperCase())) {
      return;
    }

    router[verb.toLowerCase()](route, function (req, res) {
      var requestArgs = _extends({}, args, { routeDefinition: routeDefinition, verb: verb, req: req, res: res });
      callHooks(_nodeBits.BEFORE_EXECUTE_ROUTE, requestArgs);

      implementation[verb.toLowerCase()](req, res);

      callHooks(_nodeBits.AFTER_EXECUTE_ROUTE, requestArgs);
    });
  });

  callHooks(_nodeBits.AFTER_CONFIGURE_ROUTES, args);

  app.use(router);
};